tdub.art
--------

A module for art (plots)

.. currentmodule:: tdub.art

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   canvas_from_counts

Reference
^^^^^^^^^

.. autofunction:: canvas_from_counts
